<?php
/*************************************
* WP Optin Boxes Admin Class
*************************************/

class WPOB_Admin {

	/************************************
	 * Instance of this class.
	 ************************************/
	protected static $instance = null;

        /*************************************
	 * Slug of the plugin screen.
	 ************************************/
	protected $wpob_main_screen_hook_suffix = null;
        protected $wpob_edit_screen_hook_suffix = null;
        protected $wpob_settings_screen_hook_suffix = null;
        
        /*************************************
	 * Initialize the plugin by loading admin 
         * scripts & styles and adding a settings 
         * page and menu.
	 *************************************/
	private function __construct() {

		/**************************************
		 * Call variables from public plugin class.
		 **************************************/
		$wpob_public = WPOB_Public::get_instance();
		$this->wpob_main_slug = $wpob_public->get_wpob_main_slug();
                $this->wpob_edit_slug = $wpob_public->get_wpob_edit_slug();
                $this->wpob_settings_slug = $wpob_public->get_wpob_settings_slug();
                $this->template_directory_1 = $wpob_public->get_template_directory(1);
                $this->template_directory_2 = $wpob_public->get_template_directory(2);
                $this->template_directory_3 = $wpob_public->get_template_directory(3);
                $this->template_directory_4 = $wpob_public->get_template_directory(4);
                $this->template_directory_5 = $wpob_public->get_template_directory(5);
                $this->template_directory_6 = $wpob_public->get_template_directory(6);
                $this->wpob_boxes_table = $wpob_public->get_boxes_table_name();
                $this->wpob_tracking_table = $wpob_public->get_tracking_table_name();
            
                
                /**************************************		
                * Load admin style sheet and JavaScript.
                ***************************************/
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );

                
                /**************************************		
                 * Add the options page and menu item.
                 ***************************************/
		add_action( 'admin_menu', array( $this, 'wpob_add_admin_menu' ) );

                
                /**************************************		
                 * Add an action link pointing to the
                 * options page.
                 **************************************/
		$wpob_basename = plugin_basename( plugin_dir_path( realpath( dirname( __FILE__ ) ) ) . $this->wpob_main_slug . '.php' );
		add_filter( 'plugin_action_links_' . $wpob_basename, array( $this, 'add_action_links' ) );

		
                /***************************************
		 * Admin actions and filters.
		 ***************************************/
		add_action( 'wp_ajax_create_new_box', array( $this, 'create_new_box') );
                add_action( 'wp_ajax_update_box_template', array( $this, 'update_box_template') );
                add_action( 'wp_ajax_update_box_customizations', array( $this, 'update_box_customizations') );
                add_action( 'wp_ajax_restore_to_default', array( $this, 'restore_to_default') );
                add_action( 'wp_ajax_update_box_settings', array( $this, 'update_box_settings') );
                add_action( 'wp_ajax_update_global_settings', array( $this, 'update_global_settings') );
                add_action( 'wp_ajax_delete_custom_list', array( $this, 'delete_custom_list') );
                add_action( 'wp_ajax_process_and_save_custom_html_form', array( $this, 'process_and_save_custom_html_form') );
                add_action( 'wp_ajax_delete_it', array( $this, 'delete_it') );
                add_action( 'wp_ajax_publish_the_box', array( $this, 'publish_the_box') );
                add_action( 'wp_ajax_disable_box', array( $this, 'disable_box') );
                
                add_action( 'admin_init' , array( $this , 'export_boxes_to_xml' ) );
                
	}

        
	/************************************
	 * Return an instance of this class.
	 ************************************/
	public static function get_instance() {
		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	
        /**************************************
	 * Register and enqueue admin-specific 
         * style sheet.
         * TODO
	 *************************************/
        public function enqueue_admin_styles() {

		if ( ! isset( $this->wpob_main_screen_hook_suffix ) || ! isset( $this->wpob_edit_screen_hook_suffix ) ) {
			return;
		}

		$wpob_screen = get_current_screen();
		if ( $this->wpob_main_screen_hook_suffix == $wpob_screen->id || $this->wpob_edit_screen_hook_suffix == $wpob_screen->id || $this->wpob_settings_screen_hook_suffix == $wpob_screen->id ) {
			wp_enqueue_style( $this->wpob_main_slug .'-admin-styles', ADMIN_ASSETS_URL.'/css/admin.css', array() );
                        wp_enqueue_style( 'wp-color-picker');
                        wp_enqueue_style( $this->wpob_main_slug .'-font-awesome', '//netdna.bootstrapcdn.com/font-awesome/4.2.0/css/font-awesome.min.css' );
                }       

	}

	/***************************************
	 * Register and enqueue admin-specific 
         * JavaScript.
	 ***************************************/
        public function enqueue_admin_scripts() {

		if ( ! isset( $this->wpob_main_screen_hook_suffix ) || ! isset( $this->wpob_edit_screen_hook_suffix ) ) {
			return;
		}

                $wpob_screen = get_current_screen();
                
                if($this->wpob_edit_screen_hook_suffix == $wpob_screen->id){
                    wp_enqueue_script('jquery-ui-accordion');
                }
                
		if ( $this->wpob_main_screen_hook_suffix == $wpob_screen->id || $this->wpob_edit_screen_hook_suffix == $wpob_screen->id || $this->wpob_settings_screen_hook_suffix == $wpob_screen->id ) {
                        wp_enqueue_script('wp-color-picker');
                        wp_enqueue_media();
                        
                        // Admin JS
                        wp_enqueue_script( $this->wpob_main_slug . '-admin-script', ADMIN_ASSETS_URL.'/js/admin.js', array( 'jquery' , 'wp-color-picker'));
                        $admin_data = array(
                            'choseImage' => __('Choose Image','wp-optin-boxes'),
                            'creatingBox' => __( 'Creating new box... Please wait!' , 'wp-optin-boxes' ),
                            'boxCreated' => __( 'Box Created Successfully. Redirecting...' , 'wp-optin-boxes' ),
                            'createBox' => __( 'Create Box and Proceed' , 'wp-optin-boxes' ),
                            'errorSavingToDB' => __( 'There was an error saving to database. Please try again later.' , 'wp-optin-boxes' ),
                            'errorUpdatingDB' => __( 'There was an error updating the database. Please try again later.' , 'wp-optin-boxes' ),
                            'updatingWait' => __( 'Updating... Please wait!' , 'wp-optin-boxes' ),
                            'savedRedirecting' => __( 'Saved! Redirecting...' , 'wp-optin-boxes' ),
                            'saveAndNext' => __( 'Save and Next' , 'wp-optin-boxes' ),
                            'settingsSaved' => __( 'Settings saved successfully.' , 'wp-optin-boxes' ),
                            'saveAndPublish' => __( 'Save and Publish!' , 'wp-optin-boxes' ),
                            'sureDelete' => __( 'Are you sure you want to delete this conversion box?' , 'wp-optin-boxes' ),
                            'errorDelete' => __( 'ERROR: Unable to delete the conversion box. Please try again later.' , 'wp-optin-boxes' ),
                            'flushStats' => __( 'Are you sure you want to flush all the stats for this conversion box?' , 'wp-optin-boxes' ),
                            'errorFlush' => __( 'ERROR: Unable to flush the stats. Please try again later.' , 'wp-optin-boxes' ),
                            'updatedSuccessfully' => __( 'Updated successfully.' , 'wp-optin-boxes' ),
                            'update' => __( 'Update' , 'wp-optin-boxes' ),
                            'boxPublished' => __( 'Box Published Successfully!' , 'wp-optin-boxes' ),
                            'later' => __( 'Later' , 'wp-optin-boxes' ),
                            'errorPublishing' => __( 'Error Publishing The Box!<br /><br />Reload this page and try again.' , 'wp-optin-boxes' ),
                            'done' => __( 'Done' , 'wp-optin-boxes' ),
                            'reload' => __( 'Reload' , 'wp-optin-boxes' ),
                            'errorProcessingCode' => __( 'ERROR: Unable to process the code. Please make sure you have entered proper form HTML code. Or, please contact support if problem persists.' , 'wp-optin-boxes-pro' ),
                            'pleaseEnterDetails' => __( 'Please enter both Custom List Name and Custom List Form Code.' , 'wp-optin-boxes-pro' ),
                            'deleteCustomList' => __( 'Are you sure you want to delete this custom list?' , 'wp-optin-boxes-pro' ),
                            'errorDeletingCustom' => __( 'There was an error deleting the custom list. Please try again later.' , 'wp-optin-boxes-pro' )
                        );
                        wp_localize_script( $this->wpob_main_slug . '-admin-script', 'wpobAdmin', $admin_data);
                        
                        // Real Time Box Customizer JS
                        wp_enqueue_script( $this->wpob_main_slug . "-real-time-box-customizer-js",  ADMIN_ASSETS_URL.'/js/realtimeboxcustomizer.js');
                        $rtbc_data = array(
                            'resetDataConfirmation' => __('Are you sure you want to reset the customizations to default? All design elements and content will be reset to defaults.', 'wp-optin-boxes'),
                            'resttingBtn' => __('Reseting... Please wait!','wp-optin-boxes'),
                            'resetError' => __('There was an error. Please try again later or contact support if problem persists.','wp-optin-boxes'),
                            'updatingBtn' => __('Updating... Please wait!','wp-optin-boxes'),
                            'updateSaved' => __('Saved! Redirecting...','wp-optin-boxes'),
                            'saveAndNext' => __('Save and Next','wp-optin-boxes'),
                            'updateError' => __('There was an error updating the database. Please try again later or contact support if problem persists.','wp-optin-boxes')
                        );
                        wp_localize_script( $this->wpob_main_slug . "-real-time-box-customizer-js", 'wpobRTBC', $rtbc_data);
                        
                        wp_enqueue_script( $this->wpob_main_slug . "-dd-slick",  ADMIN_ASSETS_URL.'js/jquery.ddslick.min.js');
                        wp_enqueue_script( $this->wpob_main_slug . "-lightbox",  ADMIN_ASSETS_URL.'js/lightbox.js');
		}

	}

        
	/**************************************
	 * Register admin menu and sub menus
	 **************************************/
	public function wpob_add_admin_menu() {

		$this->wpob_main_screen_hook_suffix = add_menu_page(
			__( 'WP Optin Boxes', 'wp-optin-boxes' ),
			__( 'WP Optin Boxes', 'wp-optin-boxes' ),
			'manage_options',
			$this->wpob_main_slug,
			array( $this, 'wpob_display_main_page' ),
                        ADMIN_ASSETS_URL.'/imgs/icon.png',
                        85
		);
                add_submenu_page(
                        $this->wpob_main_slug, 
                        __( 'WP Optin Boxes', 'wp-optin-boxes' ), 
                        __( 'WP Optin Boxes', 'wp-optin-boxes' ),
                        'manage_options',
                        $this->wpob_main_slug
                );
                $this->wpob_edit_screen_hook_suffix = add_submenu_page(
                        $this->wpob_main_slug, 
                        __( 'Add New Box', 'wp-optin-boxes' ), 
                        __( 'Add New Box', 'wp-optin-boxes' ),
                        'manage_options',
                        $this->wpob_edit_slug,
                        array( $this, 'wpob_display_edit_page' )
                );
                $this->wpob_settings_screen_hook_suffix = add_submenu_page(
                        $this->wpob_main_slug, 
                        __( 'Global Settings', 'wp-optin-boxes' ), 
                        __( 'Global Settings', 'wp-optin-boxes' ),
                        'manage_options',
                        $this->wpob_settings_slug,
                        array( $this, 'wpob_display_settings_page' )
                );

	}

        
	/**************************************
         * Admin pages
	 **************************************/
        
	public function wpob_display_main_page() {
		include_once( 'views/main.php' );
	}
        public function wpob_display_edit_page() {
		include_once( 'views/edit.php' );
	}
        public function wpob_display_settings_page() {
		include_once( 'views/settings.php' );
	}
        
	/***************************************
	 * Add action link to the plugins page.
	 ***************************************/
	public function add_action_links( $links ) {

		return array_merge(
			array(
				'settings' => '<a href="' . admin_url( 'admin.php?page=' . $this->wpob_edit_slug ) . '">' . __( 'Add New Box', 'wp-optin-boxes' ) . '</a>'
			),
			$links
		);

	}
        
        /***************************************
	 * Sidebar metabox content
	 ***************************************/
        
        public function wpob_sidebar() {
            include_once( 'views/sidebar.php' );
        }
        
        
        /***************************************
	 * Edit page content
	 ***************************************/
        
        public function wpob_edit_page_content($step, $id){
            
            if(!isset($step)){
                echo "<p>". __('Enter a name for your new box:','wp-optin-boxes') . "</p>"
                             . "<input type='text' name='wpob_box_name' id='wpob_box_name' class='regular-text'><br /><br />"
                             . "<input type='submit' name='wpob_create_box' id='wpob_create_box' value='". __('Create Box and Proceed','wp-optin-boxes') . "' class='button button-primary'>";
            }
            else{
                global $wpdb;
                $wpob_tbl_name = $this->wpob_boxes_table;
                switch($step){
                   case 1: include_once( 'includes/select-box-template.php' );
                           break;
                   case 2: include_once( 'includes/customize-box.php' );
                           break;
                   case 3: include_once( 'includes/box-settings.php' );
                           break;  
                   default: include_once( 'includes/select-box-template.php' );
                           break;    
                }   
            }
        }
        
        /***************************************
         * Handle AJAX call to save the new box 
         * details to databse
         * 
         * Last Updated : v1.2.1
         ***************************************/      
        public function create_new_box() {

                global $wpdb;
                $wpob_box_name = strip_tags(stripslashes($_POST['wpob_box_name']));
                $wpdb->insert($this->wpob_boxes_table, array('box_name' => $wpob_box_name), array('%s'));
                
                if($wpdb->insert_id)
                    echo $wpdb->insert_id;

                die();
        } 
    
        // Handle AJAX call to update box using ID  
        
        public function update_box_template() {
                global $wpdb;
                $wpob_data = array(
                    'box_type' => $_POST['box_type'],
                    'box_template' => $_POST['box_template']
                );
                
                if($_POST['delete_customizations'] == '1'){
                    $wpob_data['box_customizations'] = 'defaults';
                    $wpob_if_done = $wpdb->update($this->wpob_boxes_table, $wpob_data, array('id' => $_POST['box_id']), array('%d','%s','%s'), array('%d'));
                }
                else{
                    $wpob_if_done = $wpdb->update($this->wpob_boxes_table, $wpob_data, array('id' => $_POST['box_id']), array('%d','%s'), array('%d'));    
                }
            
                if($wpob_if_done === FALSE)
                    echo 0;
                else
                    echo 1;
                die();
        } 
        
        //Update box design customizations
        
        public function update_box_customizations() {
            
                global $wpdb;

                $all_customizations = $_POST['all_customizations'];
                
                if(isset($all_customizations['custom_css'])){
                    $all_customizations['custom_css'] = strip_tags($all_customizations['custom_css']);
                }
                
                $box_customizations = serialize($all_customizations);

                $wpob_if_done = $wpdb->update($this->wpob_boxes_table, array('box_customizations' => $box_customizations), array('id' => $_POST['box_id']), array('%s'), array('%d'));
                
                if($wpob_if_done === FALSE)
                    echo 0;
                else
                    echo 1;
                
                die();
                
        }
        
        //Restore customizations to default
        
        public function restore_to_default(){
                
                global $wpdb;
                
                $box_customizations = 'defaults';
                
                $wpob_if_done = $wpdb->update($this->wpob_boxes_table, array('box_customizations' => $box_customizations), array('id' => $_POST['box_id']), array('%s'), array('%d'));
                
                if($wpob_if_done === FALSE)
                    echo 0;
                else
                    echo 1;
                
                die();
        }


        // Update box settings
        
        public function update_box_settings() {
                global $wpdb;
                
                $box_name = $_POST['box_name'];
                $box_settings = array(
                    'box_fade_in' => isset($_POST['box_fade_in']) ? $_POST['box_fade_in'] : '',
                    'box_fade_in_time' => isset($_POST['box_fade_in_time']) ? $_POST['box_fade_in_time'] : '',
                    'box_make_sticky' => isset($_POST['box_make_sticky']) ? $_POST['box_make_sticky'] : '',
                    'wpob_popup_type_radio' => isset($_POST['wpob_popup_type_radio']) ? $_POST['wpob_popup_type_radio'] : '',
                    'wpob_popup_option_val' => isset($_POST['wpob_popup_option_val']) ? $_POST['wpob_popup_option_val'] : '',
                    'wpob_popup_frequency' => isset($_POST['wpob_popup_frequency']) ? $_POST['wpob_popup_frequency'] : '',
                    'wpob_popup_test_mode' => isset($_POST['wpob_popup_test_mode']) ? $_POST['wpob_popup_test_mode'] : ''
                );
                
                $box_id = $_POST['box_id'];
                
                $box_settings = serialize($box_settings);

                $wpob_if_done = $wpdb->update($this->wpob_boxes_table, array('box_name' => $box_name, 'box_settings' => $box_settings), array('id' => $box_id), array('%s'), array('%d'));
                
                if($wpob_if_done === FALSE)
                    echo 0;
                else
                    echo $box_id;
                
                die();
        }
        
        // Handles AJAX call to delete a particular box.
        
        public function delete_it(){
                global $wpdb;
                $wpob_id = $_POST['wpob_id'];
                if($wpdb->delete( $this->wpob_boxes_table, array( 'id' => $wpob_id ) )){
                    $wpdb->delete( $this->wpob_tracking_table, array( 'box_id' => $wpob_id ) );
                    echo $wpob_id;
                }
                else 
                    echo 0;
                die();
        }

        /***************************************
         * Update Global Settings
         ***************************************/
        
        public function update_global_settings(){
            $wpob_conversion_tracking = $_POST['wpob_conversion_tracking'];
            $wpob_boxes_list_default = $_POST['wpob_boxes_list_default'];
            $wpob_boxes_list_posts = $_POST['wpob_boxes_list_posts'];
            $wpob_boxes_list_pages = $_POST['wpob_boxes_list_pages'];
            
        if(update_option('wpob_default_box', $wpob_boxes_list_default) || update_option('wpob_all_posts', $wpob_boxes_list_posts) || update_option('wpob_all_pages', $wpob_boxes_list_pages) || update_option('wpob_conversion_tracking', $wpob_conversion_tracking))
                echo 1;
            else
                echo 1;
        }
        
        /***************************************
         * Publish Box
         ***************************************/
        
        public function publish_the_box(){
            
            $global_placement = $_POST['global_placement'];
            $box_id = (isset($_POST['box_id'])) ? $_POST['box_id'] : '';
            
            $wpob_default_box = get_option('wpob_default_box');
            $wpob_all_posts = get_option('wpob_all_posts');
            $wpob_all_pages = get_option('wpob_all_pages');
            
            switch($global_placement){
                case 1: update_option('wpob_default_box', $box_id);
                        if($wpob_all_posts == $box_id){
                            update_option('wpob_all_posts', 0);
                        }
                        if($wpob_all_pages == $box_id){
                            update_option('wpob_all_pages', 0);
                        }
                        break;
                case 2: if($wpob_default_box == $box_id){
                            update_option('wpob_default_box', 0);
                        }
                        update_option('wpob_all_posts', $box_id);
                        if($wpob_all_pages == $box_id){
                            update_option('wpob_all_pages', 0);
                        }
                        break;                    
                case 3: if($wpob_default_box == $box_id){
                            update_option('wpob_default_box', 0);
                        }
                        if($wpob_all_posts == $box_id){
                            update_option('wpob_all_posts', 0);
                        }
                        update_option('wpob_all_pages', $box_id);
                        break;                    
                default:if($wpob_default_box == $box_id){
                            update_option('wpob_default_box', 0);
                        }
                        if($wpob_all_posts == $box_id){
                            update_option('wpob_all_posts', 0);
                        }
                        if($wpob_all_pages == $box_id){
                            update_option('wpob_all_pages', 0);
                        }
                        break;
            }
            
            echo 1;
            die();
        }

        /***************************************
         * Show list of all the boxes
         ***************************************/
        
        public function wpob_show_boxes_list() {
            include_once('includes/show-boxes-list.php');
        }
        
        /***************************************
         * Duplicate a box
         * 
         * @since 1.2.3
         ***************************************/
        
        public function wpob_duplicate_box($box_id){
            global $wpdb;
            $wpob_tbl_name = $this->wpob_boxes_table;
            $box_data = $wpdb->get_row("SELECT * FROM $wpob_tbl_name WHERE id = $box_id", "ARRAY_A");
            
            $wpdb->insert($this->wpob_boxes_table, 
                array(
                    'box_name' => $box_data['box_name']." (". __( 'Duplicate' , 'wp-optin-boxes' ) . ")",
                    'box_type' => $box_data['box_type'], 
                    'box_template' => $box_data['box_template'],
                    'box_customizations' => $box_data['box_customizations'],
                    'box_settings' => $box_data['box_settings']
                ), 
                array(
                    '%s',
                    '%d',
                    '%s',
                    '%s',
                    '%s'
                )
            );
            if($wpdb->insert_id)
                return true;
            else
                return false;
            
        }
        
        /***************************************
         * Show dropdown list of all boxes in DB
         ***************************************/
        
        public function wpob_box_list($selected_box,$list_type,$list_id){
            global $wpdb;
            $wpob_tbl_name = $this->wpob_boxes_table;
            $boxes_list = $wpdb->get_results("SELECT id,box_name,box_type FROM $wpob_tbl_name ORDER BY id ASC","ARRAY_A");
            
            if($list_type == 'default') $first_option = __('None','wp-optin-boxes');
            else $first_option = __('Use Default','wp-optin-boxes');
            
            echo "<select name='".$list_id."' id='".$list_id."'>";
            echo "<option value='0'>".$first_option."</option>";
            foreach($boxes_list as $box){
                if($box['box_type'] != '5'){
                    if($selected_box == $box['id']){
                        $is_selected = "selected";
                    }

                    else{
                        $is_selected = "";
                    }
                    echo "<option value='".$box['id']."' ".$is_selected.">".stripcslashes($box['box_name'])."</option>";   
                }
            }
            echo "</select>";
        }
        
        /***************************************
         * Show list of all templates
         ***************************************/
        
        public function wpob_template_list($selected_template,$template_type){
                switch($template_type){
                    case 1 :    $wpob_template_main_dir_base = $this->template_directory_1.'/';
                                $wpob_template_main_dir = TEMPLATE_DIR_PATH.$this->template_directory_1.'/';
                                $wpob_template_dir_url = TEMPLATE_DIR_URL.$this->template_directory_1.'/';
                                                break;
                    case 2 :    $wpob_template_main_dir_base = $this->template_directory_2.'/';
                                $wpob_template_main_dir = TEMPLATE_DIR_PATH.$this->template_directory_2.'/';
                                $wpob_template_dir_url = TEMPLATE_DIR_URL.$this->template_directory_2.'/';
                                                break;
                    case 3 :    $wpob_template_main_dir_base = $this->template_directory_3.'/';
                                $wpob_template_main_dir = TEMPLATE_DIR_PATH.$this->template_directory_3.'/';
                                $wpob_template_dir_url = TEMPLATE_DIR_URL.$this->template_directory_3.'/';
                                                break;
                    case 4 :    $wpob_template_main_dir_base = $this->template_directory_4.'/';
                                $wpob_template_main_dir = TEMPLATE_DIR_PATH.$this->template_directory_4.'/';
                                $wpob_template_dir_url = TEMPLATE_DIR_URL.$this->template_directory_4.'/';
                                                break;
                    case 5 :    $wpob_template_main_dir_base = $this->template_directory_5.'/';
                                $wpob_template_main_dir = TEMPLATE_DIR_PATH.$this->template_directory_5.'/';
                                $wpob_template_dir_url = TEMPLATE_DIR_URL.$this->template_directory_5.'/';
                                                break;
                    case 6 :    $wpob_template_main_dir_base = $this->template_directory_6.'/';
                                $wpob_template_main_dir = TEMPLATE_DIR_PATH.$this->template_directory_6.'/';
                                $wpob_template_dir_url = TEMPLATE_DIR_URL.$this->template_directory_6.'/';
                                                break;
                }
                
                $wpob_templates = scandir($wpob_template_main_dir);
                
                $cnt = 0;
                
                echo "<div class='wpob_template_selector'><select class='wpob_template_dropdown' name='wpob_template_dropdown_".$template_type."' id='wpob_template_dropdown_".$template_type."'><option value='0'>". __('Select template','wp-optin-boxes') ."</option>";
                
                foreach ($wpob_templates as $wpob_template_dir) {
                    
                    if($wpob_template_dir === '.' || $wpob_template_dir === '..') continue;
                    
                    if (is_dir($wpob_template_main_dir . $wpob_template_dir)) {
                        
                        if($selected_template == $wpob_template_dir){
                            $is_selected = "selected";
                        }
                        
                        else{
                            $is_selected = "";
                        }
                        
                        $wpob_template_screenshot_url = AMAZON_S3_ASSETS_FOLDER . $wpob_template_main_dir_base . $wpob_template_dir . '.png';
                        echo "<option data-screenshot='".$wpob_template_screenshot_url."' value='".$wpob_template_dir."' ".$is_selected.">".$wpob_template_dir."</option>";
                        
                    }
                    
                    $cnt++;
                }
                echo "</select></div>";
        }
        
        public function get_box_name($box_id){
            global $wpdb;
            $wpob_tbl_name = $this->wpob_boxes_table;
            $wpob_the_row = $wpdb->get_row($wpdb->prepare("SELECT box_name from $wpob_tbl_name WHERE id = %d",array($box_id)));
            return stripslashes($wpob_the_row->box_name);
        }

        /***************************************
         * Include the selected template - If 
         * you make changes to this, also do so
         * with the same in WPOB_Public class.
         ***************************************/        
        
        public function include_the_template_and_settings($box_type, $box_template, $box_customizations, $box_id){
            
            if($box_type == 5 || $box_type == 6){
                echo "<div class='wpob_box_customizer'><h3>". __('Popup Lightbox Preview','wp-optin-boxes')."</h3>";
            }
            else{
                echo "<div class='wpob_box_customizer'><h3>". __('Box Preview','wp-optin-boxes')."</h3>";
            }
            
            $wpob_default_fields = $box_customizations;
            
            switch($box_type){
                    case 1 :    include_once(WPOB_TEMPLATE_DIR_PATH.$this->template_directory_1.'/'.$box_template.'/template.php');
                                break;
                    case 2 :    include_once(WPOB_TEMPLATE_DIR_PATH.$this->template_directory_2.'/'.$box_template.'/template.php');
                                break;
                    case 3 :    include_once(WPOB_TEMPLATE_DIR_PATH.$this->template_directory_3.'/'.$box_template.'/template.php');
                                break;
                    case 4 :    include_once(WPOB_TEMPLATE_DIR_PATH.$this->template_directory_4.'/'.$box_template.'/template.php');
                                break;
                    case 5 :    include_once(WPOB_TEMPLATE_DIR_PATH.$this->template_directory_5.'/'.$box_template.'/template.php');
                                break;
                    case 6 :    include_once(WPOB_TEMPLATE_DIR_PATH.$this->template_directory_6.'/'.$box_template.'/template.php');
                                break;
            }
            
            echo "</div>";
            echo "<div class='wpob_box_customizer_options'>";
            echo "<div class='wpob_nav_buttons_step_2'><a href='".admin_url( 'admin.php?page=' . $this->wpob_edit_slug )."&step=1&id=".$box_id."' class='wpob_customizer_back_button'></a><input type='submit' box_id='". $box_id ."' value='".__('Save and Next','wp-optin-boxes'). "' class='button button-primary' name='update-box-customizations' id='update-box-customizations'/>";
            echo "<button box_id='". $box_id ."' class='button' id='restore-to-default'>".__('Reset','wp-optin-boxes')."</button></div>";
            echo "<div class='wpob_box_customizer_options_main_wrap'><div class='wpob_box_customizer_options_main'><h3 class='wpob_customizer_page_title'>". __('Step 2 : Customize Box','wp-optin-boxes') ."</h3>";
            
            if($box_type == 5){
                echo "<p style='padding: 0px 15px 20px 15px; background-color: #fff; margin: 0px;'><b>Note:</b> You've selected the box type as <em>'2-Step Optin Link'</em>. This box type has two parts - optin link and email optin box (which appears as popup when you click on the optin link). This page is for customization of the email optin box. Customization of optin link is done during the last Publishing step.</p>";
            }
            
            include_once('includes/default-customizations-fields.php');
            echo "</div></div><div class='wpob_customizer_footer'><em>WP Optin Boxes</em></div></div>";
        }
        
        /***************************************
         * Get the box container setting fields
         ***************************************/        
        
        public function font_families_dropdown_list($selected_font_family, $font_familiy_area){
            
            // If you edit this, also edit the @import in admin.css
            $font_families = array(
                'Arial','Georgia','Serif','Palatino Linotype','Times New Roman',
                'Comic Sans MS','Impact','Tahoma','Verdana','Courier New',
                'Lucida Grande','Poiret One','Josefin Sans','Lobster','Anton',
                'Shadows Into Light','Gloria Hallelujah','Roboto','Oswald',
                'Raleway','Montserrat','Oxygen','Francois One','Titillium Web',
                'Indie Flower','Fjalla One','Inconsolata','Pacifico','Audiowide',
                'Dancing Script','Coming Soon'
            );
            echo "<select name='font_families_".$font_familiy_area."' id='font_families_".$font_familiy_area."'>";
            foreach($font_families as $font_family){
                
                if($selected_font_family == $font_family){
                    $selected = 'selected';
                }
                else{
                    $selected = '';
                }
                
                echo '<option value="'.$font_family.'" '.$selected.'>'.$font_family.'</option>';
            }
            echo "</select>";
        }
        
        /**************************************
         * Get dropdown list of email service 
         * providers
         **************************************/
        
        public function get_mailer_campaigns_list($mailer_id,$selected_campaign) {
            
            $getresponse = get_option('wpob_getresponse_campaigns');
            $mailchimp = get_option('wpob_mailchimp_lists');
            $aweber = get_option('wpob_aweber_lists');
            $madmimi = get_option('wpob_madmimi_lists');
            $constant_contact = get_option('wpob_constant_contact_lists');
            $campaign_monitor = get_option('wpob_campaign_monitor_lists');
            $infusionsoft = get_option('wpob_infusionsoft_lists');
            $icontact = get_option('wpob_icontact_lists');
            $pardot = get_option('wpob_pardot_lists');
            $active_campaign = get_option('wpob_active_campaign_lists');
            $gotowebinar = get_option('wpob_gotowebinar_webinars');
            
            $custom = get_option('wpob_custom_lists');
            
            $getresponse_campaigns = unserialize($getresponse);
            $mailchimp_lists = unserialize($mailchimp);
            $aweber_lists = unserialize($aweber);
            $madmimi_lists = unserialize($madmimi);
            $constant_contact_lists = unserialize($constant_contact);
            $campaign_monitor_lists = unserialize($campaign_monitor);
            $infusionsoft_lists = unserialize($infusionsoft);
            $icontact_lists = unserialize($icontact);
            
            if (class_exists('WYSIJA')){
                $modelList = WYSIJA::get('list', 'model');
                $mail_poet_lists = $modelList->get(array('name', 'list_id'), array('is_enabled' => 1));
            }
            $pardot_lists = unserialize($pardot);
            $active_campaign_lists = unserialize($active_campaign);
            $gotowebinar_lists = unserialize($gotowebinar);
            $custom_lists = unserialize($custom);
            
            $feedburner_uri = get_option('wpob_feedburner_uri');
            
            if($feedburner_uri != '' or $getresponse_campaigns != '' or $mailchimp_lists != '' or $aweber_lists != '' or $madmimi_lists != '' or $constant_contact_lists != '' or $campaign_monitor_lists != '' or $infusionsoft_lists != '' or $icontact_lists != '' or $mail_poet_lists != '' or $pardot_lists != '' or $custom_lists != '' or $active_campaign_lists !='' or $gotowebinar_lists !=''){

                //GetResponse
                
                echo '<select id="input_campaign_name" name="input_campaign_name">';
                
                if($getresponse_campaigns != ''){
                    foreach($getresponse_campaigns as $gr_id => $gr_name){
                        if($gr_id == $selected_campaign && $mailer_id == 1){
                            echo '<option data-description="GetResponse" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/gr-sm.png" data-mailer-id="1" value="'.$gr_id.'" selected>'.$gr_name.'</option>';
                        }
                        else{
                            echo '<option data-description="GetResponse" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/gr-sm.png" data-mailer-id="1" value="'.$gr_id.'" >'.$gr_name.'</option>';
                        }
                    }                    
                }
                
                //MailChimp
                
                if($mailchimp_lists != ''){
                    foreach($mailchimp_lists as $mc_id => $mc_name){
                        if($mc_id == $selected_campaign && $mailer_id == 2){
                            echo '<option data-description="MailChimp" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/mc-sm.png" data-mailer-id="2" value="'.$mc_id.'" selected>'.$mc_name.'</option>';
                        }
                        else{
                            echo '<option data-description="MailChimp" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/mc-sm.png" data-mailer-id="2" value="'.$mc_id.'" >'.$mc_name.'</option>';
                        }
                    }
                }

                //Aweber
                
                if($aweber_lists != ''){
                    foreach($aweber_lists as $aweber_id => $aweber_name){
                        if($aweber_id == $selected_campaign && $mailer_id == 3){
                            echo '<option data-description="Aweber" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/aweber-sm.png" data-mailer-id="3" value="'.$aweber_id.'" selected>'.$aweber_name.'</option>';
                        }
                        else{
                            echo '<option data-description="Aweber" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/aweber-sm.png" data-mailer-id="3" value="'.$aweber_id.'" >'.$aweber_name.'</option>';
                        }
                    }                    
                }
                
                //MadMimi
                
                if($madmimi_lists != ''){
                    foreach($madmimi_lists as $madmimi_id => $madmimi_name){
                        if($madmimi_id == $selected_campaign && $mailer_id == 4){
                            echo '<option data-description="Mad Mimi" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/madmimi-sm.png" value="'.$madmimi_id.'" selected>'.$madmimi_name.'</option>';
                        }
                        else{
                            echo '<option data-description="Mad Mimi" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/madmimi-sm.png" value="'.$madmimi_id.'" >'.$madmimi_name.'</option>';
                        }
                    }                    
                }
                
                // Constant Contact
                
                if($constant_contact_lists != ''){
                    foreach($constant_contact_lists as $constant_contact_id => $constant_contact_name){
                        if($constant_contact_id == $selected_campaign && $mailer_id == 5){
                            echo '<option data-description="Constant Contact" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/constant-contact-sm.png" value="'.$constant_contact_id.'" selected>'.$constant_contact_name.'</option>';
                        }
                        else{
                            echo '<option data-description="Constant Contact" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/constant-contact-sm.png" value="'.$constant_contact_id.'" >'.$constant_contact_name.'</option>';
                        }
                    }                    
                }
                
                // Campaign Monitor
                
                if($campaign_monitor_lists != ''){
                    foreach($campaign_monitor_lists as $campaign_monitor_id => $campaign_monitor_name){
                        if($campaign_monitor_id == $selected_campaign && $mailer_id == 6){
                            echo '<option data-description="Campaign Monitor" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/campaign-monitor-sm.png" value="'.$campaign_monitor_id.'" selected>'.$campaign_monitor_name.'</option>';
                        }
                        else{
                            echo '<option data-description="Campaign Monitor" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/campaign-monitor-sm.png" value="'.$campaign_monitor_id.'" >'.$campaign_monitor_name.'</option>';
                        }
                    }                    
                }
                
                //Infusionsoft
                
                if($infusionsoft_lists != ''){
                    foreach($infusionsoft_lists as $infusionsoft_id => $infusionsoft_name){
                        if($infusionsoft_id == $selected_campaign && $mailer_id == 7){
                            echo '<option data-description="Infusionsoft" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/infusionsoft-sm.png" value="'.$infusionsoft_id.'" selected>'.$infusionsoft_name.'</option>';
                        }
                        else{
                            echo '<option data-description="Infusionsoft" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/infusionsoft-sm.png" value="'.$infusionsoft_id.'" >'.$infusionsoft_name.'</option>';
                        }
                    }                    
                }
                
                //iContact
                
                if($icontact_lists != ''){
                    foreach($icontact_lists as $icontact_id => $icontact_name){
                        if($icontact_id == $selected_campaign && $mailer_id == 8){
                            echo '<option data-description="iContact" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/icontact-sm.png" value="'.$icontact_id.'" selected>'.$icontact_name.'</option>';
                        }
                        else{
                            echo '<option data-description="iContact" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/icontact-sm.png" value="'.$icontact_id.'" >'.$icontact_name.'</option>';
                        }
                    }                    
                }
                
                //MailPoet
                
                if($mail_poet_lists != ''){
                    foreach($mail_poet_lists as $mail_poet_list){
                        if($mail_poet_list['list_id'] == $selected_campaign && $mailer_id == 9){
                            echo '<option data-description="MailPoet" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/mailpoet-sm.png" value="'.$mail_poet_list['list_id'].'" selected>'.$mail_poet_list['name'].'</option>';
                        }
                        else{
                            echo '<option data-description="MailPoet" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/mailpoet-sm.png" value="'.$mail_poet_list['list_id'].'" >'.$mail_poet_list['name'].'</option>';
                        }
                    }                    
                }
                
                // Pardot
                
                if($pardot_lists != ''){
                    foreach($pardot_lists as $pardot_id => $pardot_name){
                        if($pardot_id == $selected_campaign && $mailer_id == 10){
                            echo '<option data-description="Pardot" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/pardot-sm.png" value="'.$pardot_id.'" selected>'.$pardot_name.'</option>';
                        }
                        else{
                            echo '<option data-description="Pardot" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/pardot-sm.png" value="'.$pardot_id.'" >'.$pardot_name.'</option>';
                        }
                    }                    
                }
                
                // Custom Lists
                
                if($custom_lists != ''){
                    foreach($custom_lists as $custom_lists_id => $custom_list){
                        if($custom_lists_id == $selected_campaign && $mailer_id == 99){
                            echo '<option data-description="Custom List" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/custom-sm.png" value="'.$custom_lists_id.'" selected>'.$custom_list['custom_list_name'].'</option>';
                        }
                        else{
                            echo '<option data-description="Custom List" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/custom-sm.png" value="'.$custom_lists_id.'" >'.$custom_list['custom_list_name'].'</option>';
                        }
                    }                    
                }
                
                //Feedburner
                
                if($feedburner_uri != ''){
                    if($feedburner_uri == $selected_campaign && $mailer_id == 11){
                        echo '<option data-description="Feedburner" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/feedburner-sm.png" value="'.$feedburner_uri.'" selected>'.$feedburner_uri.'</option>';
                    }
                    else{
                        echo '<option data-description="Feedburner" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/feedburner-sm.png" value="'.$feedburner_uri.'" >'.$feedburner_uri.'</option>';
                    }
                }
                
                //Active Campaign
                
                if($active_campaign_lists != ''){
                    foreach($active_campaign_lists as $active_campaign_id => $active_campaign_name){
                        if($active_campaign_id == $selected_campaign && $mailer_id == 12){
                            echo '<option data-description="Active Campaign" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/active-campaign-sm.jpg" value="'.$active_campaign_id.'" selected>'.$active_campaign_name.'</option>';
                        }
                        else{
                            echo '<option data-description="Active Campaign" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/active-campaign-sm.jpg" value="'.$active_campaign_id.'" >'.$active_campaign_name.'</option>';
                        }
                    }
                }
                
                //GotoWebinar
                
                if($gotowebinar_lists != ''){
                    foreach($gotowebinar_lists as $gotowebinar_id => $gotowebinar_name){
                        if($gotowebinar_id == $selected_campaign && $mailer_id == 13){
                            echo '<option data-description="GotoWebinar" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/gotowebinar-sm.png" value="'.$gotowebinar_id.'" selected>'.$gotowebinar_name.'</option>';
                        }
                        else{
                            echo '<option data-description="GotoWebinar" data-imagesrc="'.ADMIN_ASSETS_URL.'imgs/gotowebinar-sm.png" value="'.$gotowebinar_id.'" >'.$gotowebinar_name.'</option>';
                        }
                    }
                }
                
                echo "</select>";
                
            }
            else{
                echo "<p>". __('No campaigns/lists found. Please integrate your email service provider first to select a campaign/list for this conversion box.','wp-optin-boxes') ." <a href='".admin_url( 'admin.php?page=' . $this->wpob_settings_slug )."&step=2'>". __('Click here to integrate now.' , 'wp-optin-boxes' ) ."</a></p>";
            }
        }

        /***************************************
         * Process and save custom html form
         ***************************************/
        
        public function process_and_save_custom_html_form(){
            
                $custom_list_form_html = $_POST['custom_list_form_html'];
                $custom_list_name = $_POST['custom_list_name'];
                include_once( MAILERS_DIR_PATH . 'custom/phpQuery/phpQuery.php');

                try {
                    $HTML = phpQuery::newDocumentHTML($custom_list_form_html);
                    $labels = $HTML->find('label');
                    $buttons = $HTML->find('button');
                    $disallowed_atts = array('style', 'class');

                    foreach ((object) $buttons as $i => $button) {
                        $atts = '';
                        for ($m = $button->attributes->length - 1; $m >= 0; --$m) {
                            if (in_array((string) $button->attributes->item($m)->nodeName, $disallowed_atts))
                                pq($button)->removeAttr($button->attributes->item($m)->nodeName);
                        }
                    }

                    // Prepare rest of variables.
                    $inputs = $HTML->find('form')->find(':input')->not(':input[type=reset]');
                    $input_html = '';
                    $input_num = count($inputs);

                    // Build out all input elements into the form.
                    foreach ((object) $inputs as $n => $input) {
                        // Prep variables for checking type of input.
                        $single_input = '';
                        $email_input = false;
                        $name_input = false;
                        $type_hidden = false;
                        $input_name = '';

                        // Avoid looping over body tag.
                        if ('body' == (string) $input->nodeName)
                            continue;

                        for ($m = $input->attributes->length - 1; $m >= 0; --$m) {
                            if (in_array((string) $input->attributes->item($m)->nodeName, $disallowed_atts) || 'data-om-type' == (string) $input->attributes->item($m)->nodeName)
                                continue;
                            if ('type' == (string) $input->attributes->item($m)->nodeName && '\"hidden\"' == (string) $input->attributes->item($m)->nodeValue) {
                                $email_input = $name_input = false;
                                $type_hidden = true;
                            }
                            
                            if ('type' == (string) $input->attributes->item($m)->nodeName && '\"email\"' == (string) $input->attributes->item($m)->nodeValue) {
                                $email_input = true;
                            }
                            
                            if ('name' == (string) $input->attributes->item($m)->nodeName)
                                $input_name = strtolower((string) $input->attributes->item($m)->nodeValue);
                            if ('value' == (string) $input->attributes->item($m)->nodeName)
                                $input_value = strtolower((string) $input->attributes->item($m)->nodeValue);
                            
                        }
                        
                        // Automatically add proper data types based on possible type of input.
                        $this_input_name = trim($input_name,'\"');
                        $this_input_value = trim($input_value,'\"');
                        if($this_input_name != 'submit' && $this_input_value != 'submit'){
                            if(preg_match('#(name)#i',$this_input_name)){
                                $wpob_name_name = $this_input_name;
                            }
                            elseif(preg_match('#(email)#i',$this_input_name) || $email_input == true){
                                $wpob_email_name = $this_input_name;
                            }
                            else{
                                $wpob_other_fields[$this_input_name] = $this_input_value;
                            }
                        }
                    }

                    // Now grab form element.
                    $forms = $HTML->find('form')->empty();
                    

                    // Build out the main <form> element with all attributes.
                    foreach ((object) $forms as $i => $form) {
                        // Avoid looping over body tag.
                        if ('body' == (string) $form->nodeName)
                            continue;

                        for ($k = $form->attributes->length - 1; $k >= 0; --$k) {
                            if (in_array((string) $form->attributes->item($k)->nodeName, $disallowed_atts) || 'id' == (string) $form->attributes->item($k)->nodeName || 'target' == (string) $form->attributes->item($k)->nodeName)
                                continue;

                            if((string) $form->attributes->item($k)->nodeName == 'action'){
                                $action_url = (string) $form->attributes->item($k)->nodeValue;
                                $action_url = trim($action_url,'\"');
                            }
                        }
                    }

                    
                } catch (Exception $e) {
                    echo json_encode(array('error' => $e->getMessage()));
                    die;
                }
                
                if($wpob_email_name != ''){
                    $custom_html_list_data = array(
                        'custom_list_name' => $custom_list_name,
                        'action_url' => $action_url,
                        'emails_name_tag' => $wpob_email_name,
                        'names_name_tag' => $wpob_name_name,
                        'other_fields' => $wpob_other_fields 
                    );

                    //print_r($custom_html_list_data);

                    $custom_lists = get_option('wpob_custom_lists');

                    if($custom_lists == ''){
                        $custom_lists_array = array($custom_html_list_data);
                    }
                    else{
                        $custom_lists_array = unserialize($custom_lists);
                        array_push($custom_lists_array, $custom_html_list_data);
                    }
                    $custom_lists = serialize($custom_lists_array);
                    update_option('wpob_custom_lists',$custom_lists);
                    echo 1;
                }
                else{
                    $custom_html_list_data = array(
                        'custom_list_name' => $custom_list_name,
                        'action_url' => $action_url,
                        'emails_name_tag' => $wpob_email_name,
                        'names_name_tag' => $wpob_name_name,
                        'other_fields' => $wpob_other_fields 
                    );
                    print_r($custom_html_list_data);
                    echo $email_input;
                }
                die();

                // Save the sanitized HTML string.
                //$meta['custom_html'] = trim(esc_html($sanitized_html));
                
        }
        
        /***************************************
         * Get all custom email lists
         ***************************************/
        
        public function get_all_custom_email_lists(){
            $all_custom_lists = get_option('wpob_custom_lists');
            if($all_custom_lists == ''){
                echo "";
            }
            else{
                $custom_lists = unserialize($all_custom_lists);
                foreach($custom_lists as $k => $list){
                   echo "<tr><td style='padding: 10px 10px;'>".$list['custom_list_name']."</td><td style='text-align: center; padding: 10px;'><a style='color: red; cursor: pointer;' id='wpob_delete_custom_list' data-custom-list-id='".$k."'>". __('Delete', 'wp-optin-boxes-pro' ) ."</a></td></tr>";
                }
            }
        }
        
        /***************************************
         * Delete custom email lists
         ***************************************/
        
        public function delete_custom_list(){
            $custom_list_id = $_POST['custom_list_id'];
            $all_custom_lists = get_option('wpob_custom_lists');
            $custom_lists = unserialize($all_custom_lists);
            unset($custom_lists[$custom_list_id]);
            $updated_custom_lists = serialize($custom_lists);
            update_option('wpob_custom_lists',$updated_custom_lists);
            echo 1;
            die();
        }
        
        /****************************************
         * Checklist of categories
         ****************************************/
        
        public function checklist_of_categories() {
            $selected_cats = array();
            $categories = get_categories();
            if ( $categories ){
                echo "<div class='wpob_cat_checklist'>";
                wp_category_checklist( 0, 0, $selected_cats, false, null, false );
                echo "</div>";
            }
        }
        
        /***************************************
         * Delete custom template
         ***************************************/
        
        public function disable_box(){
            $box_id = (isset($_POST['box_id'])) ? $_POST['box_id'] : 0;
            $box_status = (isset($_POST['box_status'])) ? $_POST['box_status'] : '';
            
            global $wpdb;
            $wpob_if_done = $wpdb->update($this->wpob_boxes_table, array('box_status' => $box_status), array('id' => $box_id), array('%d'), array('%d'));
            
            if($wpob_if_done === FALSE)
                echo 0;
            else
                echo 1;
            
            die();
        }
        
        /***************************************
         * Export boxes to XML if asked for
         ***************************************/
        
        public function export_boxes_to_xml(){
            
            if(isset($_POST['export-boxes'])){

                global $wpdb;
                $wpob_tbl_name = $this->wpob_boxes_table;
                $boxes_list = $wpdb->get_results("SELECT * FROM $wpob_tbl_name ORDER BY id ASC","ARRAY_A");
                
                /* Create a file name */
                $sitename = sanitize_key( get_bloginfo( 'name' ) );
                $filename = $sitename . '-wpob-' . date( 'Y-m-d' ) . '.xml';

                
                /* Print header */
                header( 'Content-Description: File Transfer' );
                header( 'Content-Disposition: attachment; filename=' . $filename );
                header( 'Content-Type: text/xml; charset=' . get_option( 'blog_charset' ), true );

                /* Print comments */
                echo "<!-- WP Optin Boxes Export Data -->\n";
                echo '<boxes>';
                foreach ( $boxes_list as $box ) { ?>
                    <item>
                        <box_name><?php echo esc_attr($box['box_name']); ?></box_name>
                        <box_status><?php echo absint($box['box_status']); ?></box_status>
                        <box_type><?php echo absint($box['box_type']); ?></box_type>
                        <box_template><?php echo esc_attr($box['box_template']); ?></box_template>
                        <box_customizations><?php echo $box['box_customizations']; ?></box_customizations>
                        <box_settings><?php echo $box['box_settings']; ?></box_settings>
                    </item>
                <?php }
                echo '</boxes>';
                exit();
            }
            
        }
        
        /***************************************
         * Import boxes from XML
         ***************************************/
        
        public function import_boxes_from_xml(){
            if(isset($_POST['import-boxes'])){
                if(isset($_FILES['wpob_import_xml']['error']) && $_FILES['wpob_import_xml']['size'] != 0){
                    $imported_xml = $_FILES['wpob_import_xml'];
                    $imported_xml_name = $_FILES['wpob_import_xml']['name'];
                    $ext = pathinfo($imported_xml_name, PATHINFO_EXTENSION);
                    if($ext != 'xml'){
                        echo "<div class='error'><p>". __('Invalid file format. Please upload an XML file.', 'wp-optin-boxes') ."</p></div>";
                    }
                    else{
                        $boxes = simplexml_load_file($imported_xml['tmp_name']) or die("Error: There was an error parsing your export file.");
                        foreach($boxes as $box){
                            global $wpdb;
                            $wpdb->insert($this->wpob_boxes_table, 
                                array(
                                    'box_name' => $box->box_name,
                                    'box_status' => $box->box_status,
                                    'box_type' => $box->box_type, 
                                    'box_template' => $box->box_template,
                                    'box_customizations' => $box->box_customizations,
                                    'box_settings' => $box->box_settings
                                ), 
                                array(
                                    '%s',
                                    '%d',
                                    '%d',
                                    '%s',
                                    '%s',
                                    '%s'
                                )
                            );
                        }
                        if($wpdb->insert_id){
                            echo "<div class='updated'><p>".__('Boxes imported successfully!','wp-optin-boxes')."</p></div>";
                        }
                        else{
                            echo "<div class='error'><p>".__('There was an error importing','wp-optin-boxes')."</p></div>";
                        }
                    }
                }
                else{
                    echo "<div class='error'><p>". __('No file selected. Please select an XML file before clicking on Import.', 'wp-optin-boxes') ."</p></div>";
                }
                
            }
        }
        
}

