<?php

/*************************************
* WP Optin Boxes Public Class
*************************************/

class WPOB_Public {

        const WPOB_AUTHOR_NAME = 'Ram Shengale';
        
	/*********************************
	 * Default slugs
	 *********************************/
	protected $wpob_main_slug = 'wp-optin-boxes';
        protected $wpob_edit_slug = 'wp-optin-boxes/edit';
        protected $wpob_ab_tests_slug = 'wp-optin-boxes/ab-tests';
        protected $wpob_edit_ab_test_slug = 'wp-optin-boxes/edit-ab-tests';
	protected $wpob_stats_slug = 'wp-optin-boxes/statistics';
        protected $wpob_settings_slug = 'wp-optin-boxes/settings';
        
        protected $template_directory_1 = 'email-optin';
        protected $template_directory_2 = 'video-email-optin';
        protected $template_directory_3 = 'call-to-action';
        protected $template_directory_4 = 'video-call-to-action';
        protected $template_directory_5 = '2-step-optin-link';
        protected $template_directory_6 = 'smart-popup';
        
        protected $main_table = 'wp_optin_boxes';
        protected $tracking_table = 'wpob_tracking';

        /*********************************
	 * Instance of this class.
	 *********************************/
	protected static $instance = null;
                
	/*********************************
	 * Initialize the plugin by setting 
         * localization and loading public 
         * scripts and styles.
	 *********************************/
	private function __construct() {
                
		/*********************************
                 * Activate plugin when new blog 
                 * is added
                 *********************************/
		add_action( 'wpmu_new_blog', array( $this, 'activate_new_site' ) );
                
		/*********************************
                 * Load public-facing style sheet,
                 * JavaScript and shortcode.
                 *********************************/
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
                
                add_action( 'wp_footer', array( $this, 'in_footer' ) );
                add_filter( 'the_content', array( $this, 'show_box') );
                add_shortcode( 'wpob' , array( $this, 'run_shortcode') );
        
                add_action( 'wp_ajax_add_new_contact', array( $this, 'add_new_contact') );
                add_action( 'wp_ajax_nopriv_add_new_contact', array( $this, 'add_new_contact') );
                
                /***************************************
		 * Init functions
		 ***************************************/
                add_action( 'init' , array ($this, 'update_table_structure') );

	}
        
	/***************************************
	 * Return the variable values
	 ***************************************/
        
	public function get_wpob_main_slug() {
		return $this->wpob_main_slug;
	}
        
        public function get_wpob_edit_slug() {
		return $this->wpob_edit_slug;
	}
        
        public function get_wpob_ab_tests_slug(){
                return $this->wpob_ab_tests_slug;
        }
        public function get_wpob_edit_ab_test_slug(){
                return $this->wpob_edit_ab_test_slug;
        }
        public function get_wpob_stats_slug() {
		return $this->wpob_stats_slug;
	}
        
        public function get_wpob_settings_slug() {
		return $this->wpob_settings_slug;
	}
        
        public function get_template_directory($dir) {
            switch ($dir){
                case 1: return $this->template_directory_1;
                        break;
                case 2: return $this->template_directory_2;
                        break;
                case 3: return $this->template_directory_3;
                        break;
                case 4: return $this->template_directory_4;
                        break;
                case 5: return $this->template_directory_5;
                        break;
                case 6: return $this->template_directory_6;
                        break;
            }
            
        }
        public function get_boxes_table_name(){
            global $wpdb;
            return $wpdb->prefix.$this->main_table;
        }
        public function get_tracking_table_name(){
            global $wpdb;
            return $wpdb->prefix.$this->tracking_table;
        }

	/***************************************
	 * Return an instance of this class.
	 ***************************************/
	public static function get_instance() {
                if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}
        

	/***************************************
	 * Fired when the plugin is activated.
	 ***************************************/
	public static function activate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide  ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_activate();
				}

				restore_current_blog();

			} else {
				self::single_activate();
			}

		} else {
			self::single_activate();
		}

	}

        
	/***************************************
	 * Fired when the plugin is deactivated.
	 ***************************************/
	public static function deactivate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_deactivate();

				}

				restore_current_blog();

			} else {
				self::single_deactivate();
			}

		} else {
			self::single_deactivate();
		}

	}

        /***************************************
	 * Fired when a new site is activated with 
         * a WPMU environment.
	 ****************************************/
	public function activate_new_site( $blog_id ) {

		if ( 1 !== did_action( 'wpmu_new_blog' ) ) {
			return;
		}

		switch_to_blog( $blog_id );
		self::single_activate();
		restore_current_blog();

	}

	/***************************************
	 * Get all blog ids of blogs in the current 
         * network that are:
	 * - not archived
	 * - not spam
	 * - not deleted
	 ***************************************/
	private static function get_blog_ids() {

		global $wpdb;

		// get an array of blog ids
		$sql = "SELECT blog_id FROM $wpdb->blogs
			WHERE archived = '0' AND spam = '0'
			AND deleted = '0'";

		return $wpdb->get_col( $sql );

	}

        /***************************************
	 * Fired for each blog when the plugin 
         * is activated.
	 ***************************************/
	private static function single_activate() {
                
                global $wpdb;
                
                $wpob_tbl_1 = $wpdb->prefix.'wp_optin_boxes';
                $wpdb->query("CREATE TABLE IF NOT EXISTS $wpob_tbl_1 (
                    id INT(9) NOT NULL AUTO_INCREMENT,
                    box_status int(1) DEFAULT 1,
                    box_name VARCHAR(80) NOT NULL,
                    box_type int(9),
                    box_template VARCHAR(120),
                    box_customizations longtext,
                    box_settings VARCHAR(350),
                    UNIQUE KEY id (id)
                ) DEFAULT CHARSET=utf8;","%s");
                
                
                $wpob_tbl_2 = $wpdb->prefix.'wpob_tracking';
                $wpdb->query("CREATE TABLE IF NOT EXISTS $wpob_tbl_2 (
                    id INT( 11 ) NOT NULL AUTO_INCREMENT PRIMARY KEY ,
                    ip VARCHAR( 16 ) NOT NULL ,
                    host VARCHAR( 100 ) NOT NULL ,
                    visitdate DATETIME NOT NULL ,
                    visitedpage VARCHAR(255) NOT NULL ,
                    referring VARCHAR( 255 ) NOT NULL ,
                    visittype ENUM('visit', 'boxview', 'click', 'optin'),
                    box_id INT(9) NOT NULL DEFAULT 0 
                ) DEFAULT CHARSET=utf8;","%s");
                 
                add_option('wpob_default_box', 0 , '', 'yes' );
                add_option('wpob_all_posts', 0 , '', 'yes' );
                add_option('wpob_all_pages', 0 , '', 'yes' );
                add_option('wpob_enable_credit_link', 0 , '', 'yes' );
                add_option('wpob_database_version', 1);
                add_option('wpob_conversion_tracking', 1 , '', 'yes');
        }
        
        /***************************************
	 * Update Table Structure After Update
         * 
         * Current Version : 1
	 ***************************************/
        
        public function update_table_structure() {
                global $wpdb;
                $wpob_tbl = $wpdb->prefix.'wp_optin_boxes';
                
                if(get_option('wpob_database_version') != 1){
                    $all_columns = $wpdb->get_row("SELECT * FROM $wpob_tbl");
                    if(!isset($all_columns->box_status)){
                        $wpdb->query("ALTER TABLE $wpob_tbl ADD box_status INT(1) NOT NULL DEFAULT 1");
                        if($done != false)
                            update_option('wpob_database_version', 1); // From original 0;
                    }
                }
        }

        /***************************************
	 * Fired for each blog when the plugin 
         * is deactivated.
	 ***************************************/
	private static function single_deactivate() {
		// Noting so far.
	}

        /***************************************
	 * Register and enqueue public-facing 
         * style sheet.
	 ***************************************/
	public function enqueue_styles() {
		wp_enqueue_style( $this->wpob_main_slug . '-plugin-styles', PUBLIC_ASSETS_URL .'css/public.css', array() );
	}

        /***************************************
	 * Register and enqueues public-facing 
         * JavaScript files.
	 ***************************************/
	public function enqueue_scripts() {
		// wp_enqueue_script( $this->wpob_main_slug . '-plugin-script', PUBLIC_ASSETS_URL .'js/public.js', array( 'jquery' ) );
	}
        
        
        /***************************************
         * Show the box
         ***************************************/
        
        public function show_the_box($id,$attributes = null){
            
            $wpob_tracking = WPOB_Tracker::get_instance();            
            
            global $wpdb;

            $wpob_tbl_name = $this->get_boxes_table_name();
            $wpob_the_row = $wpdb->get_row($wpdb->prepare("SELECT * from $wpob_tbl_name WHERE id = %d", array($id)));

            if (isset($wpob_the_row)) {
                $box_status = $wpob_the_row->box_status;
                $box_type = $wpob_the_row->box_type;
                $box_template = $wpob_the_row->box_template;
                $box_customizations = $wpob_the_row->box_customizations;
                $box_settings = $wpob_the_row->box_settings;
            } else {
                return;
            }
            
            $box_id = $id;
            
            if($box_status != 1){
                ob_start();
                return;
            }
            
            if($box_customizations != null AND $box_customizations != 'defaults'){
                $wpob_default_fields = unserialize($box_customizations);
                $wpob_default_fields = $this->sanitise_array($wpob_default_fields);
                $wpob_default_fields['defaults'] = 'custom';
            }
            else{
                $wpob_default_fields['defaults'] = 'defaults';
            }
            
            if(isset($box_settings)){
            
                $wpob_box_settings = unserialize($box_settings);

                if($wpob_box_settings['box_fade_in'] == '1'){
                    $wpob_settings_data['box_fade_in'] = "wpob_fade_in";
                }
                else{
                    $wpob_settings_data['box_fade_in'] = "wpob_nothing";
                }

                $wpob_settings_data['box_fade_in_time'] = $wpob_box_settings['box_fade_in_time'];

                if($wpob_box_settings['box_make_sticky'] == '1'){
                    $wpob_settings_data['box_make_sticky'] = "box_make_sticky";
                }
                else{
                    $wpob_settings_data['box_make_sticky'] = "wpob_nothing";
                }
        
            }
            else{
                $wpob_settings_data['box_fade_in'] = "wpob_nothing";
                $wpob_settings_data['box_fade_in_time'] = "0";
                $wpob_settings_data['box_make_sticky'] = "wpob_nothing";
            }
            
            $wpob_popup_type_radio = (isset($wpob_box_settings['wpob_popup_type_radio'])) ? $wpob_box_settings['wpob_popup_type_radio'] : 0;
            $wpob_popup_option_val = (isset($wpob_box_settings['wpob_popup_option_val'])) ? $wpob_box_settings['wpob_popup_option_val'] : 0;
            $wpob_popup_frequency = (isset($wpob_box_settings['wpob_popup_frequency'])) ? $wpob_box_settings['wpob_popup_frequency'] : 10;
            $wpob_popup_test_mode = (isset($wpob_box_settings['wpob_popup_test_mode'])) ? $wpob_box_settings['wpob_popup_test_mode'] : 0;
            
            ob_start();
            
            if($wpob_popup_test_mode == 1){
                echo '<script>document.cookie="wpob-popup-'.$box_id.'=; expires=-1;path=/";</script>';
            }
            
            echo '<!--------------------------------------><!-- Optin/Call-to-Action Box Made Using : -------><!-- WP Optin Boxes - -------------><!-- http://wpoptinboxes.com --><!-------------------------------------->';
            echo '<div class="'. $wpob_settings_data['box_make_sticky'].'_offset"></div>';
            
            switch($box_type){
                case 1 :    include(WPOB_TEMPLATE_DIR_PATH.$this->get_template_directory(1).'/'.$box_template.'/template.php');
                            break;
                case 2 :    include(WPOB_TEMPLATE_DIR_PATH.$this->get_template_directory(2).'/'.$box_template.'/template.php');
                            break;
                case 3 :    include(WPOB_TEMPLATE_DIR_PATH.$this->get_template_directory(3).'/'.$box_template.'/template.php');
                            break;
                case 4 :    include(WPOB_TEMPLATE_DIR_PATH.$this->get_template_directory(4).'/'.$box_template.'/template.php');
                            break;
                case 5 :    if(isset($attributes['style']) && $attributes['style'] != 'image'){
                                $anchor = $attributes['text'];
                                if($attributes['style'] == 'none' || $attributes['style'] == ''){
                                    $attributes['style'] = 'none_none';
                                }
                                $style = explode('_', $attributes['style']);
                            }
                            else{
                                $img_url = isset($attributes['image_url']) ? $attributes['image_url'] : '';
                                $anchor = '<img src="'.$img_url.'" class="wpcb_2_step_button_img_'.$box_id.'"/>';
                                $style = explode('_', 'none_none');
                            }
                            echo '<a id="wpob_two_step_optin_link_'.$box_id.'" class="wpob_button_'.$style[1].' wpob_two_step_optin_link_'.$style[0].'">'.$anchor.'</a>';
                            echo '<style>div.wpob_template_main.wpob_template_main_'.$box_id.'{display: none;}</style>';
                            include(WPOB_TEMPLATE_DIR_PATH.$this->get_template_directory(5).'/'.$box_template.'/template.php');
                            break;
                case 6 :    echo '<div class="wpob_popup_data" id="wpob_popup_data_'.$box_id.'" data-popup-type="'.$wpob_popup_type_radio.'" data-popup-val="'.$wpob_popup_option_val.'" data-popup-frequency="'.$wpob_popup_frequency.'"></div>';
                            echo '<style>div.wpob_template_main.wpob_template_main_'.$box_id.'{display: none;}</style>';
                            include(WPOB_TEMPLATE_DIR_PATH.$this->get_template_directory(6).'/'.$box_template.'/template.php');
                            break;
            }
            
            if(get_option('wpob_enable_credit_link') == 1){
                echo "<span class='wpob_credit_link'>". __("Made using <a target='_blank' href='http://wpoptinboxes.com'>WP Optin Boxes</a>",'wp-optin-boxes') ."</span>";
            }
            
            echo  '<!------------------------------><!-- Optin/Call-to-Action Box Ends Here --><!------------------------------>';
            
            if (isset($wpob_the_row) && get_option('wpob_conversion_tracking') == 1) {
                $wpob_tracking->log_new_visit($box_id);
            }

        }
        
        /******************************
         * Main shortcode [wpob]
         ******************************/

        public function run_shortcode($atts) {
            $attributes = shortcode_atts(array(
                'id' => 0,
                'text' => 'Click Here',
                'style' => 'none',
                'image_url' => 'http://'
            ), $atts);
            $this->show_the_box($attributes['id'], $attributes);
            return ob_get_clean();
        }

        public function show_box($content){
            $posttype = get_post_type();
        
            $wpob_default_box = get_option('wpob_default_box');
            $wpob_all_posts = get_option('wpob_all_posts');
            $wpob_all_pages = get_option('wpob_all_pages');
            
            $attributes = array(
                'text' => 'Click Here',
                'style' => 'none',
                'image_url' => 'http://'
            );

            if($wpob_all_posts == $wpob_all_pages && $wpob_all_posts != 0){
                $this->show_the_box($wpob_all_posts, $attributes);
            }else if($posttype == 'post' && $wpob_all_posts != 0){
                $this->show_the_box($wpob_all_posts, $attributes);
            }
            else if($posttype == 'page' && $wpob_all_pages != 0){
                $this->show_the_box($wpob_all_pages, $attributes);
            }
            else if($wpob_default_box != 0){
                $this->show_the_box($wpob_default_box, $attributes);
            }
            else {
                ob_start();
            }

            $final_output = ob_get_contents();  // get buffer content
            ob_end_clean();
            if(isset($final_output)){ 
                return $content.$final_output; 
            }
            else{ 
                return $content; 
            }
        }
        
        public function in_footer(){
            //echo $_COOKIE["wpob-useradded"];
        }
        
        /***************************************
         * Sanitise array
         ***************************************/
        
        function sanitise_array ($data = array()) {
            if (!is_array($data) || !count($data)) {
                    return array();
            }

            foreach ($data as $k => $v) {
                    if (!is_array($v) && !is_object($v)) {
                            if($k != 'content_text'){
                                $data[$k] = esc_attr(stripslashes(trim($v)));
                            }
                            else{
                                $data[$k] = stripslashes(trim($v));
                            }
                    }
                    if (is_array($v)) {
                            $data[$k] = sanitise_array($v);
                    }
            }

            return $data;
        }
        /****************************************
         * Add new contact to respective campaign
         * or list
         ***************************************/
        
        function add_new_contact(){
            $name = $_POST['name'];
            $email = $_POST['email'];
            $mailer_id = $_POST['mailer_id'];
            $campaign_id = $_POST['campaign_id'];
            $tracker_id = $_POST['tracker_id'];
            
            switch($mailer_id){
                // GetResponse
                case 1: $getresponse_api_key = get_option('wpob_getresponse_api_key');
                        include_once(plugin_dir_path(dirname(__FILE__)).'admin/mailers/getresponse-api.php');
                        $getresponse = new jsonRPCClient('http://api2.getresponse.com');
                        try{
                            $result_contact = $getresponse->add_contact($getresponse_api_key, array ('campaign' => $campaign_id,'name' => $name,'email' => $email,'cycle_day' => 0));
                            global $wpdb;
                            $wpob_tbl_name = $this->get_tracking_table_name();
                            if(get_option('wpob_conversion_tracking') == 1)
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                            echo 1;
                        }
                        catch (Exception $e){
                            echo $e;
                        }
                        break;
                // MailChimp
                case 2: $mailchimp_api_key = get_option('wpob_mailchimp_api_key');
                        include_once(plugin_dir_path(dirname(__FILE__)).'admin/mailers/mailchimp-api.php');
                        $mailchimp = new MCAPI($mailchimp_api_key);
                        $merge_vars = array('FNAME' => $name, 'LNAME' => '');
                        $retval = $mailchimp->listSubscribe($campaign_id, $email, $merge_vars, 'html', true, true);
                        if($mailchimp->errorCode){
                            echo 0;
                        }
                        else {
                            global $wpdb;
                            $wpob_tbl_name = $this->get_tracking_table_name();
                            if(get_option('wpob_conversion_tracking') == 1)
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                            echo 1;
                        }
                        break;
                // Aweber
                case 3: include_once(plugin_dir_path(dirname(__FILE__)).'admin/mailers/aweber_api/aweber_api.php');
                        try {
                            $aweber_api_key = get_option('wpob_aweber_api_key');
                            $aweber_data = unserialize($aweber_api_key);
                            $aweber = new AWeberAPI($aweber_data[0], $aweber_data[1]);
                            $account = $aweber->getAccount($aweber_data[2], $aweber_data[3]);
                            $account_id = $account->id;
                            $listURL = "/accounts/".$account_id."/lists/".$campaign_id;
                            $list = $account->loadFromUrl($listURL);
                            $params = array(
                                'email' => $email,
                                'name' => $name
                            );
                            $subscribers = $list->subscribers;
                            $new_subscriber = $subscribers->create($params);
                            global $wpdb;
                            $wpob_tbl_name = $this->get_tracking_table_name();
                            if(get_option('wpob_conversion_tracking') == 1)
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                            echo 1;
                        }
                        catch (Exception $exc)
                        {
                            echo 0;
                        }
                        break;
                
                // MadMimi
                case 4 :$madmimi_api_key = get_option('wpob_madmimi_api_key');
                        $madmimi_data = unserialize($madmimi_api_key );
                        if (!class_exists('MadMimi')) {
                            include_once(MAILERS_DIR_PATH.'madmimi/MadMimi.class.php');
                        }
                        $madmimi = new MadMimi($madmimi_data['username'], $madmimi_data['api_key']);
                        $info = array(
                            'email' => $email,
                            'firstName' => $name,
                            'add_list' => $campaign_id
                        );
                        $madmimi->AddUser($info);
                        global $wpdb;
                        $wpob_tbl_name = $this->get_tracking_table_name();
                        if(get_option('wpob_conversion_tracking') == 1)
                            $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                        echo 1;
                        die();
                        break;
                // Constant Contact
                case 5 :$constant_contact_access_token = get_option('wpob_constant_contact_api_key');
                        $cc_response = wp_remote_get('https://api.constantcontact.com/v2/contacts?api_key=wcp88fmhmyxmegwbpvcpz36x&access_token=' . $constant_contact_access_token . '&email=' . $email);
                        $cc_contact = json_decode(wp_remote_retrieve_body($cc_response));
                        if (!empty($cc_contact->results)) {
                            echo 0;
                        } else {
                            $args = $body = array();
                            $body['email_addresses'] = array();
                            $body['email_addresses'][0]['id'] = $campaign_id;
                            $body['email_addresses'][0]['status'] = 'ACTIVE';
                            $body['email_addresses'][0]['email_address'] = $email;
                            $body['lists'] = array();
                            $body['lists'][0]['id'] = $campaign_id;
                            $body['first_name'] = $name;

                            $args['body'] = json_encode($body);

                            $args['headers']['Content-Type'] = 'application/json';
                            $args['headers']['Content-Length'] = strlen(json_encode($body));
                            $create = wp_remote_post('https://api.constantcontact.com/v2/contacts?api_key=wcp88fmhmyxmegwbpvcpz36x&access_token=' . $constant_contact_access_token , $args);
                            global $wpdb;
                            $wpob_tbl_name = $this->get_tracking_table_name();
                            if(get_option('wpob_conversion_tracking') == 1)
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                            echo 1;
                        }
                        die();
                        break;
                // Campaign Monitor
                case 6 :$campaign_monitor_api_key = get_option('wpob_campaign_monitor_api_key');
                        if (!class_exists('CS_Rest_Subscribers')) {
                            include_once(MAILERS_DIR_PATH. 'campaign-monitor/csrest_subscribers.php');
                        }
                        $campaign_monitor = new CS_Rest_Subscribers($campaign_id, $campaign_monitor_api_key);
                        $result = $campaign_monitor->add(array('EmailAddress' => $email, 'Name' => $name, 'Resubscribe' => true, 'CustomFields' => array(array('Key' => 'WP Optin Boxes Pro', 'Value' => true))));
                        if ($result->was_successful()) {
                            global $wpdb;
                            $wpob_tbl_name = $this->get_tracking_table_name();
                            if(get_option('wpob_conversion_tracking') == 1)
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                            echo 1;
                        } else {
                            echo 0;
                        }
                        die();
                        break;
                // Infusion Soft (not checked)
                case 7 :$infusionsoft_api = get_option('wpob_infusionsoft_api_key');
                        $infusionsoft_api_data = unserialize($infusionsoft_api);
                        $infusionsoft_subdomain = $infusionsoft_api_data['subdomain'];
                        $infusionsoft_api_key = $infusionsoft_api_data['api_key'];
                        if (!class_exists('iSDK')) {
                            include_once(MAILERS_DIR_PATH. 'infusionsoft/isdk.php');
                        }
                        try {
                            $infusionsoft = new iSDK();
                            $infusionsoft->cfgCon($infusionsoft_subdomain, $infusionsoft_api_key, 'throw');
                        } catch (iSDKException $e) {
                            echo 0;
                            die();
                        }
                        try {
                            $contact_id = $infusionsoft->addCon(array('FirstName' => $name, 'Email' => $email));
                            $group_add = $infusionsoft->grpAssign($contact_id, $campaign_id); //$campaign_id = group_id
                        } catch (iSDKException $e) {
                            echo 0;
                            die();
                        }
                        global $wpdb;
                        $wpob_tbl_name = $this->get_tracking_table_name();
                        if(get_option('wpob_conversion_tracking') == 1)
                            $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                        echo 1;
                        die();
                        break;
                // iContact
                case 8 :$icontact_api = get_option('wpob_icontact_api_key');
                        $icontact_api_data = unserialize($icontact_api);
                        $icontact_username = $icontact_api_data['username'];
                        $icontact_app_password = $icontact_api_data['app_password'];
                        $icontact_app_id = $icontact_api_data['api_key'];
                        if (!class_exists('iContactApi')) {
                            include_once(MAILERS_DIR_PATH. 'icontact/iContactApi.php');
                        }
                            try {
                                iContactApi::getInstance()->setConfig(array(
                                    'appId' => $icontact_app_id,
                                    'apiPassword' => $icontact_app_password,
                                    'apiUsername' => $icontact_username
                                ));
                                $icontact = iContactApi::getInstance();
                                $contact = $icontact->addContact($email, 'normal', null, $name);
                                
                                // Subscribe the contact to the list.
                                $subscribe = $icontact->subscribeContactToList($contact->contactId, $campaign_id);
                                global $wpdb;
                                $wpob_tbl_name = $this->get_tracking_table_name();
                                if(get_option('wpob_conversion_tracking') == 1)
                                    $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                                echo 1;
                            } catch (Exception $e) {
                                echo 0;
                            }

                        die();
                        break;
                // MailPoet
                case 9 :$mailpoet_data = array(
                            'user' => array('email' => $email, 'firstname' => $name),
                            'user_list' => array('list_ids' => array($campaign_id))
                        );

                        // Add subscriber to MailPoet.
                        $userHelper = WYSIJA::get('user', 'helper');
                        $userHelper->addSubscriber($mailpoet_data);
                        global $wpdb;
                        $wpob_tbl_name = $this->get_tracking_table_name();
                        if(get_option('wpob_conversion_tracking') == 1)
                            $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                        $this->data['success'] = true;
                        echo 1;
                        die();
                        break;
                // Pardot
                case 10:$pardot_api_data_serialized = get_option('wpob_pardot_api_key');
                        $pardot_api_data = unserialize($pardot_api_data_serialized);
                        if (!class_exists('Pardot_OM_API')) {
                            include_once(MAILERS_DIR_PATH. 'pardot/pardot-api-class.php');
                        }
                        $pardot = new Pardot_OM_API($pardot_api_data);
                        $pardot->authenticate($pardot_api_data);

                        $url = 'https://pi.pardot.com/api/prospect/version/3/do/create/email/' . $email . '?campaign_id=' . $campaign_id . '&first_name=' . $name . '&api_key=' . $pardot->api_key . '&user_key=' . $pardot_api_data['user_key'];
                        $contact = wp_remote_post($url);
                        $xml_resp = new SimpleXMLElement(wp_remote_retrieve_body($contact));
                        $response = json_decode(json_encode($xml_resp));

                        if (isset($response->err))
                            echo 0;
                        else{
                            global $wpdb;
                            $wpob_tbl_name = $this->get_tracking_table_name();
                            if(get_option('wpob_conversion_tracking') == 1)
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                            echo 1;
                        }
                        die();                        
                        break;
                //Custom List        
                case 99:$all_custom_lists_serialized = get_option('wpob_custom_lists');
                        $all_custom_lists = unserialize($all_custom_lists_serialized);
                        
                        $list_data = $all_custom_lists[$campaign_id];
                        
                        $url = $list_data['action_url'];
                        
                        $post_data = array( 
                            $list_data['names_name_tag'] => $name, 
                            $list_data['emails_name_tag'] => $email
                        );
                        
                        if($list_data['other_fields'] != ''){
                            $post_data = array_merge($post_data, $list_data['other_fields']);
                        }
                        
                        $response = wp_remote_post( $url, array(
                                'method' => 'POST',
                                'timeout' => 45,
                                'redirection' => 5,
                                'httpversion' => '1.0',
                                'blocking' => true,
                                'headers' => array(),
                                'body' => $post_data,
                                'cookies' => array()
                            )
                        );
                        
                        global $wpdb;                        
                        $wpob_tbl_name = $this->get_tracking_table_name();
                        if(get_option('wpob_conversion_tracking') == 1)
                            $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                        
                        echo 1;
                        die();
                        break;
                
                // Feedburner
                case 11:$feedburner_uri = get_option('wpob_feedburner_uri');
                        global $wpdb;
                        $wpob_tbl_name = $this->get_tracking_table_name();
                        if(get_option('wpob_conversion_tracking') == 1)
                            $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                        echo 1;
                        break;
                
                // Active Campaign
                case 12: $active_campaign_api_data_serialized = get_option('wpob_active_campaign_api_key');
                        $active_campaign_api_data = unserialize($active_campaign_api_data_serialized);
                    
                        include_once(plugin_dir_path(dirname(__FILE__)).'admin/mailers/active-campaign/ActiveCampaign.class.php');

                        $active_campaign = new ActiveCampaign( $active_campaign_api_data['api_url'], $active_campaign_api_data['api_key']);

                        if (!(int)$active_campaign->credentials_test()) {
                            echo 0;
                            die();
                            break;
                        }

                        $contact = array(
                                "email"              => $email,
                                "first_name"         => $name,
                                "p[{$campaign_id}]"      => $campaign_id,
                                "status[{$campaign_id}]" => 1, // "Active" status
                        );

                        $contact_sync = $active_campaign->api("contact/sync", $contact);

                        if (!(int)$contact_sync->success) {
                            echo 0;
                            die();
                            break;
                        }
                        else{
                            if(get_option('wpob_conversion_tracking') == 1){
                                global $wpdb;
                                $wpob_tbl_name = $this->get_tracking_table_name();
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                                echo 1;
                            }
                        }
                        break;

                // GotoWebinar
                case 13: $gotowebinar_api_data_serialized = get_option('wpob_gotowebinar_api_key');
                        $gotowebinar_api_data = unserialize($gotowebinar_api_data_serialized);
                    
                        include_once(MAILERS_DIR_PATH.'gotowebinar-api.php');
                        
                        $gotowebinar = new Citrix('1WFXRh5bNVTl4IfASVdg5HVzwTJnck0m');
                    
                        $gotowebinar->set_organizer_key($gotowebinar_api_data['api_key']);
                        $gotowebinar->set_access_token($gotowebinar_api_data['access_token']);
                        
                        $parts = explode(" ", $name);
                        $lastname = array_pop($parts);
                        if(!empty($parts)){
                            $firstname = implode(" ", $parts);
                        }
                        else{
                            $firstname = $lastname;
                            $lastname = ' ';
                        }
                        
                        $registrant = array(
                            "email"              => $email,
                            "first_name"         => $firstname,
                            "last_name"         => $lastname
                        );
                        
                        $registered = $gotowebinar->citrixonline_create_registrant_of_webinar($campaign_id,$registrant);

                        if (!$registered) {
                            echo 0;
                            die();
                            break;
                        }
                        else{
                            if(get_option('wpob_conversion_tracking') == 1){
                                global $wpdb;
                                $wpob_tbl_name = $this->get_tracking_table_name();
                                $wpdb->update($wpob_tbl_name, array('visittype' => 'optin'), array('id' => $tracker_id), array('%s'), array('%d'));
                                echo 1;
                            }
                        }
                        break;
            }
            die();
        }

}
